@@ -3,7 +3,7 @@
 
 -- |
 -- Module      : Database.Relational.Arrow
--- Copyright   : 2015-2017 Kei Hibino
+-- Copyright   : 2015-2018 Kei Hibino
 -- License     : BSD3
 --
 -- Maintainer  : ex8k.hibino@gmail.com
@@ -47,9 +47,10 @@ module Database.Relational.Arrow (
 
   assign,
 
-  derivedUpdate', derivedUpdate,
-  derivedInsertValue', derivedInsertValue,
-  derivedDelete', derivedDelete,
+  update', update, updateNoPH,
+  updateAllColumn', updateAllColumn, updateAllColumnNoPH,
+  insertValue', insertValue, insertValueNoPH,
+  delete', delete, deleteNoPH,
 
   QueryA,
 
@@ -60,6 +61,11 @@ module Database.Relational.Arrow (
   Orderings, Window, Assignings,
 
   AssignStatement, Register, RestrictedStatement,
+
+  -- * Deprecated
+  derivedUpdate', derivedUpdate,
+  derivedInsertValue', derivedInsertValue,
+  derivedDelete', derivedDelete,
   ) where
 
 import Control.Category (Category)
@@ -76,9 +82,10 @@ import Database.Relational hiding
    relation, relation', aggregateRelation, aggregateRelation', uniqueRelation',
    groupBy', key, key', set, bkey, rollup, cube, groupingSets,
    orderBy', orderBy, asc, desc, partitionBy, over,
-   derivedUpdate', derivedUpdate,
-   derivedInsertValue', derivedInsertValue,
-   derivedDelete', derivedDelete,
+   update', update, updateNoPH, derivedUpdate', derivedUpdate,
+   updateAllColumn', updateAllColumn, updateAllColumnNoPH,
+   insertValue', insertValue, insertValueNoPH, derivedInsertValue', derivedInsertValue,
+   delete', delete, deleteNoPH, derivedDelete', derivedDelete,
    QuerySimple, QueryAggregate, QueryUnique, Window, Register)
 import qualified Database.Relational as Monadic
 import qualified Database.Relational.Monad.Trans.Aggregating as Monadic
@@ -416,32 +423,101 @@ assign :: Monad m
        -> Assignings r m (Record Flat v) ()
 assign t = queryA (`Monadic.assignTo` t)
 
--- | Same as 'Monadic.derivedUpdate''.
+-- | Same as 'Monadic.update''.
+--   Make 'Update' from assigning statement arrow using configuration.
+update' :: TableDerivable r => Config -> AssignStatement r (PlaceHolders p) -> Update p
+update' config = Monadic.update' config . runQueryA
+
+-- | Same as 'Monadic.update'.
+--   Make 'Update' from assigning statement arrow.
+update :: TableDerivable r => AssignStatement r (PlaceHolders p) -> Update p
+update = Monadic.update . runQueryA
+
+-- | Same as 'Monadic.updateNoPH'.
+--   Make 'Update' from assigning statement arrow.
+updateNoPH :: TableDerivable r => AssignStatement r () -> Update ()
+updateNoPH = Monadic.updateNoPH . runQueryA
+
+-- | Same as 'Monadic.updateAllColumn''.
+--   Make 'Update' from restrected statement arrow.
+updateAllColumn' :: (PersistableWidth r, TableDerivable r)
+                 => Config
+                 -> RestrictedStatement r (PlaceHolders p)
+                 -> Update (r, p)
+updateAllColumn' config = Monadic.updateAllColumn' config . runQueryA
+
+-- | Same as 'Monadic.updateAllColumn'.
+--   Make 'Update' from restrected statement arrow.
+updateAllColumn :: (PersistableWidth r, TableDerivable r)
+                => RestrictedStatement r (PlaceHolders p)
+                -> Update (r, p)
+updateAllColumn = Monadic.updateAllColumn . runQueryA
+
+-- | Same as 'Monadic.updateAllColumnNoPH'.
+--   Make 'Update' from restrected statement arrow.
+updateAllColumnNoPH :: (PersistableWidth r, TableDerivable r)
+                    => RestrictedStatement r ()
+                    -> Update r
+updateAllColumnNoPH = Monadic.updateAllColumnNoPH . runQueryA
+
+-- | Same as 'Monadic.insertValue''.
+--   Make 'Insert' from register arrow using configuration.
+insertValue' :: TableDerivable r => Config -> Register r (PlaceHolders p) -> Insert p
+insertValue' config = Monadic.insertValue' config . ($ ()) . runQueryA
+
+-- | Same as 'Monadic.insertValue'.
+--   Make 'Insert' from register arrow.
+insertValue :: TableDerivable r => Register r (PlaceHolders p) -> Insert p
+insertValue = Monadic.insertValue . ($ ()) . runQueryA
+
+-- | Same as 'Monadic.insertValueNoPH'.
+--   Make 'Insert' from register arrow.
+insertValueNoPH :: TableDerivable r => Register r () -> Insert ()
+insertValueNoPH = Monadic.insertValueNoPH . ($ ()) . runQueryA
+
+
+-- | Same as 'Monadic.delete''.
+--   Make 'Update' from restrict statement arrow using configuration.
+delete' :: TableDerivable r => Config -> RestrictedStatement r (PlaceHolders p) -> Delete p
+delete' config = Monadic.delete' config . runQueryA
+
+-- | Same as 'Monadic.delete'.
+--   Make 'Update' from restrict statement arrow.
+delete :: TableDerivable r => RestrictedStatement r (PlaceHolders p) -> Delete p
+delete = Monadic.delete . runQueryA
+
+-- | Same as 'Monadic.deleteNoPH'.
+--   Make 'Update' from restrict statement arrow.
+deleteNoPH :: TableDerivable r => RestrictedStatement r () -> Delete ()
+deleteNoPH = Monadic.deleteNoPH . runQueryA
+
+{-# DEPRECATED derivedUpdate' "use `update'` instead of this." #-}
+-- | Same as 'Monadic.update''.
 --   Make 'Update' from assigning statement arrow using configuration.
 derivedUpdate' :: TableDerivable r => Config -> AssignStatement r (PlaceHolders p) -> Update p
-derivedUpdate' config = Monadic.derivedUpdate' config . runQueryA
+derivedUpdate' = update'
 
--- | Same as 'Monadic.derivedUpdate'.
---   Make 'Update' from assigning statement arrow.
+{-# DEPRECATED derivedUpdate "use `update` instead of this." #-}
+-- | Deprecated.
 derivedUpdate :: TableDerivable r => AssignStatement r (PlaceHolders p) -> Update p
-derivedUpdate = Monadic.derivedUpdate . runQueryA
+derivedUpdate = update
 
--- | Same as 'Monadic.derivedInsertValue''.
---   Make 'Insert' from register arrow using configuration.
+{-# DEPRECATED derivedInsertValue' "use `insertValue'` instead of this." #-}
+-- | Deprecated.
 derivedInsertValue' :: TableDerivable r => Config -> Register r (PlaceHolders p) -> Insert p
-derivedInsertValue' config = Monadic.derivedInsertValue' config . ($ ()) . runQueryA
+derivedInsertValue' = insertValue'
 
--- | Same as 'Monadic.derivedInsertValue'.
---   Make 'Insert' from register arrow.
+{-# DEPRECATED derivedInsertValue "use `insertValue` instead of this." #-}
+-- | Deprecated.
 derivedInsertValue :: TableDerivable r => Register r (PlaceHolders p) -> Insert p
-derivedInsertValue = Monadic.derivedInsertValue . ($ ()) . runQueryA
+derivedInsertValue = insertValue
 
--- | Same as 'Monadic.derivedDelete''.
---   Make 'Update' from restrict statement arrow using configuration.
+{-# DEPRECATED derivedDelete' "use `derivedDelete'` instead of this." #-}
+-- | Deprecated.
 derivedDelete' :: TableDerivable r => Config -> RestrictedStatement r (PlaceHolders p) -> Delete p
-derivedDelete' config = Monadic.derivedDelete' config . runQueryA
+derivedDelete' = delete'
 
--- | Same as 'Monadic.derivedDelete'.
---   Make 'Update' from restrict statement arrow.
+{-# DEPRECATED derivedDelete "use `derivedDelete` instead of this." #-}
+-- | Deprecated.
 derivedDelete :: TableDerivable r => RestrictedStatement r (PlaceHolders p) -> Delete p
-derivedDelete = Monadic.derivedDelete . runQueryA
+derivedDelete = delete
