@@ -75,12 +75,11 @@ all'X = relation $ do
   return $ a ! intA0'
 
 assignX :: Update ()
-assignX = derivedUpdate $ \_proj -> do
+assignX = updateNoPH $ \_proj ->
   intA0' <-# value (0 :: Int32)
-  return unitPlaceHolder
 
 registerX :: Insert (String, Maybe String)
-registerX = derivedInsertValue $ do
+registerX = insertValue $ do
   intC0' <-# value 1
   (ph1, ()) <- placeholder (\ph' -> strC1' <-# ph')
   intC2' <-# value 2
@@ -622,27 +621,25 @@ exps =
   ]
 
 insertX :: Insert SetA
-insertX =  derivedInsert id'
+insertX =  insert id'
 
 insertI :: Insert SetI
-insertI =  derivedInsert id'
+insertI =  insert id'
 
 insertQueryX :: InsertQuery ()
-insertQueryX =  derivedInsertQuery setAFromB setA
+insertQueryX =  insertQuery setAFromB setA
 
 updateKeyX :: KeyUpdate Int32 SetA
 updateKeyX =  primaryUpdate tableOfSetA
 
 updateX :: Update ()
-updateX =  derivedUpdate $ \proj -> do
+updateX =  updateNoPH $ \proj -> do
   strA2' <-# value "X"
   wheres $ proj ! strA1' .=. value "A"
-  return unitPlaceHolder
 
 deleteX :: Delete ()
-deleteX =  derivedDelete $ \proj -> do
+deleteX =  deleteNoPH $ \proj ->
   wheres $ proj ! strA1' .=. value "A"
-  return unitPlaceHolder
 
 effs :: [Test]
 effs =
@@ -665,42 +662,38 @@ effs =
   ]
 
 updateExistsX :: Update ()
-updateExistsX = derivedUpdate $ \proj -> do
+updateExistsX = updateNoPH $ \proj -> do
   strA2' <-# value "X"
   wheres . exists
     =<< (queryList . relation $ do
             b <- query setB
             wheres $ b ! intB0' .=. proj ! intA0'
             return b)
-  return unitPlaceHolder
 
 updateScalarX :: Update ()
-updateScalarX = derivedUpdate $ \proj -> do
+updateScalarX = updateNoPH $ \proj -> do
   strA2' <-# value "X"
   sb <- queryScalar . unsafeUnique . relation $ do
     b <- query setB
     wheres $ b ! intB0' .=. value 0
     return $ b ! intB0'
   wheres $ just (proj ! intA0') .=. sb
-  return unitPlaceHolder
 
 deleteExistsX :: Delete ()
-deleteExistsX =  derivedDelete $ \proj -> do
+deleteExistsX =  deleteNoPH $ \proj ->
   wheres . exists
     =<< (queryList . relation $ do
             b <- query setB
             wheres $ b ! intB0' .=. proj ! intA0'
             return b)
-  return unitPlaceHolder
 
 deleteScalarX :: Delete ()
-deleteScalarX = derivedDelete $ \proj -> do
+deleteScalarX = deleteNoPH $ \proj -> do
   sb <- queryScalar . unsafeUnique . relation $ do
     b <- query setB
     wheres $ b ! intB0' .=. value 0
     return $ b ! intB0'
   wheres $ just (proj ! intA0') .=. sb
-  return unitPlaceHolder
 
 correlated :: [Test]
 correlated =
