@@ -75,12 +75,11 @@ all'X = relation $ proc () -> do
   returnA -< a ! intA0'
 
 assignX :: Update ()
-assignX = derivedUpdate $ proc _proj -> do
+assignX = updateNoPH $ proc _proj ->
   assign intA0' -< value (0 :: Int32)
-  returnA -< unitPlaceHolder
 
 registerX :: Insert (String, Maybe String)
-registerX = derivedInsertValue $ proc () -> do
+registerX = insertValue $ proc () -> do
   assign intC0' -< value 1
   (ph1, ()) <- placeholder -< proc ph' -> do assign strC1' -< ph'
   assign intC2' -< value 2
@@ -533,27 +532,25 @@ exps =
   ]
 
 insertX :: Insert SetA
-insertX =  derivedInsert id'
+insertX =  insert id'
 
 insertI :: Insert SetI
-insertI =  derivedInsert id'
+insertI =  insert id'
 
 insertQueryX :: InsertQuery ()
-insertQueryX =  derivedInsertQuery setAFromB setA
+insertQueryX =  insertQuery setAFromB setA
 
 updateKeyX :: KeyUpdate Int32 SetA
 updateKeyX =  primaryUpdate tableOfSetA
 
 updateX :: Update ()
-updateX =  derivedUpdate $ proc proj -> do
+updateX =  updateNoPH $ proc proj -> do
   assign strA2' -< value "X"
   wheres -< proj ! strA1' .=. value "A"
-  returnA -< unitPlaceHolder
 
 deleteX :: Delete ()
-deleteX =  derivedDelete $ proc proj -> do
+deleteX =  deleteNoPH $ proc proj -> do
   wheres -< proj ! strA1' .=. value "A"
-  returnA -< unitPlaceHolder
 
 effs :: [Test]
 effs =
